"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _useThemeProps = _interopRequireDefault(require("../../hooks/useThemeProps.js"));
var _useModifiers = _interopRequireDefault(require("../../hooks/useModifiers.js"));
var _index = require("../../style/index.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const modifiersOptions = {
  color: true,
  margins: true,
  typography: true,
  backgroundColor: true,
  flex: true
};
var writingDirectionTypes = /*#__PURE__*/function (writingDirectionTypes) {
  writingDirectionTypes["RTL"] = "rtl";
  writingDirectionTypes["LTR"] = "ltr";
  return writingDirectionTypes;
}(writingDirectionTypes || {});
/**
 * @description: A wrapper for Text component with extra functionality like modifiers support
 * @extends: Text
 * @extendsLink: https://reactnative.dev/docs/text
 * @modifiers: margins, color, typography
 * @example: https://github.com/wix/react-native-ui-lib/blob/master/demo/src/screens/componentScreens/TextScreen.tsx
 * @image: https://github.com/wix/react-native-ui-lib/blob/master/demo/showcase/Text/Modifiers.png?raw=true, https://github.com/wix/react-native-ui-lib/blob/master/demo/showcase/Text/Transformation.png?raw=true, https://github.com/wix/react-native-ui-lib/blob/master/demo/showcase/Text/Highlights.png?raw=true
 */
function Text(props, ref) {
  const themeProps = (0, _useThemeProps.default)(props, 'Text');
  const {
    style,
    flex: propsFlex,
    children,
    as,
    color: propsColor,
    center,
    uppercase,
    lowerCase,
    underline,
    ...others
  } = themeProps;
  const {
    typography,
    color: modifierColor,
    backgroundColor,
    margins,
    flexStyle
  } = (0, _useModifiers.default)(themeProps, modifiersOptions);
  const color = propsColor || modifierColor;
  const TextContainer = (0, _react.useMemo)(() => {
    return as ?? _reactNative.Text;
  }, [as]);
  const textStyle = [styles.container, typography, color && {
    color
  }, backgroundColor && {
    backgroundColor
  }, flexStyle, margins, center && styles.centered, uppercase && styles.uppercase, underline && styles.underline, style];
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(TextContainer, {
    ...others,
    style: textStyle,
    ref: ref,
    children: children
  });
}
const styles = _reactNative.StyleSheet.create({
  container: {
    backgroundColor: 'transparent',
    color: _index.Colors.$textDefault,
    ...(_reactNative.Platform.OS === 'ios' ? {
      writingDirection: _reactNative.I18nManager.isRTL ? writingDirectionTypes.RTL : writingDirectionTypes.LTR
    } : {
      textAlign: 'left'
    })
  },
  centered: {
    textAlign: 'center'
  },
  uppercase: {
    textTransform: 'uppercase'
  },
  underline: {
    textDecorationLine: 'underline'
  },
  highlight: {
    color: _index.Colors.grey30
  },
  notHighlight: {
    color: undefined
  }
});
var _default = exports.default = /*#__PURE__*/(0, _react.forwardRef)(Text);
//# sourceMappingURL=text.js.map