"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _useThemeProps = _interopRequireDefault(require("../../hooks/useThemeProps.js"));
var _useModifiers = _interopRequireDefault(require("../../hooks/useModifiers.js"));
var _index = require("../../hooks/index.js");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const modifiersOptions = {
  backgroundColor: true,
  borderRadius: true,
  paddings: true,
  margins: true,
  alignments: true,
  flex: true,
  position: true,
  gap: true
};

/**
 * @description: An enhanced View component
 * @extends: View
 * @extendsLink: https://reactnative.dev/docs/view
 * @modifiers: margins, paddings, alignments, background, borderRadius
 */
function View(props, ref) {
  const themeProps = (0, _useThemeProps.default)(props, 'View');
  const {
    renderDelay,
    style,
    left,
    top,
    right,
    bottom,
    flex: propsFlex,
    inaccessible,
    children,
    backgroundColor: backgroundColorProps,
    as,
    ...others
  } = themeProps;
  const {
    backgroundColor: backgroundColorModifiers,
    borderRadius,
    paddings,
    margins,
    alignments,
    flexStyle,
    positionStyle,
    gap
  } = (0, _useModifiers.default)(themeProps, modifiersOptions);
  const [ready, setReady] = (0, _index.useSafeState)(!renderDelay);
  (0, _react.useEffect)(() => {
    let timer;
    if (renderDelay) {
      timer = setTimeout(() => {
        setReady(true);
      }, renderDelay);
    }
    return () => {
      clearTimeout(timer);
    };
  }, []);
  const ViewContainer = (0, _react.useMemo)(() => {
    return as ?? _reactNative.View;
  }, [as]);
  const _style = (0, _react.useMemo)(() => {
    const backgroundColor = backgroundColorProps || backgroundColorModifiers;
    return [backgroundColor && {
      backgroundColor
    }, borderRadius && {
      borderRadius
    }, gap && {
      gap
    }, flexStyle, positionStyle, paddings, margins, alignments, style];
  }, [backgroundColorProps, backgroundColorModifiers, borderRadius, flexStyle, positionStyle, paddings, margins, alignments, gap, style]);
  if (!ready) {
    return null;
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(ViewContainer, {
    accessibilityElementsHidden: inaccessible,
    importantForAccessibility: inaccessible ? 'no-hide-descendants' : undefined,
    ...others,
    style: _style,
    ref: ref,
    children: children
  });
}
;
var _default = exports.default = /*#__PURE__*/(0, _react.forwardRef)(View);
//# sourceMappingURL=view.js.map