"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useForceUpdate;
var _react = require("react");
var _useSafeState = _interopRequireDefault(require("./useSafeState.js"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/**
 * Returns a function that can be called to force a re-render.
 * This is useful when you need to force a re-render but don't have access to the component's state.
 * @returns A function that can be called to force a re-render.
 * @example
 * function MyComponent() {
 *  const update = useUpdate();
 * return <button onClick={update}>Update</button>;
 * }
 */
function useForceUpdate() {
  const [, setState] = (0, _useSafeState.default)({});
  return (0, _react.useCallback)(() => setState({}), []);
}
;
//# sourceMappingURL=useForceUpdate.js.map