"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useSafeState;
var _react = require("react");
/**
 * setState that is safe to call after component unmounts.
 * @param initialState - initial state or function that returns initial state
 * @returns [state, safedSetState]
 * @example
 * function MyComponent() {
 * const [state, setState] = useSafeState(0);
 * return <button onClick={() => setState(state + 1)}>Increment</button>;
 * }
 */
function useSafeState(initialState) {
  const [state, setState] = (0, _react.useState)(initialState);
  const safeRef = (0, _react.useRef)(true);
  const safed = newState => {
    if (!safeRef.current) return; // stop set
    return setState(newState);
  };
  (0, _react.useEffect)(() => () => {
    safeRef.current = false;
  }, []);

  // @ts-ignore
  return [state, safed];
}
//# sourceMappingURL=useSafeState.js.map