import { type TextStyle, type ViewStyle } from 'react-native';
import { DesignTokens } from '../style';
import { BorderRadiusesLiterals } from '../style/borderRadiuses';
import { TypographyPresets } from '../style/typographyPresets';
import { colorsPalette } from '../style/colorsPalette';
import type { Dictionary } from '../typings/common';
export declare const FLEX_KEY_PATTERN: RegExp;
export declare const PADDING_KEY_PATTERN: RegExp;
export declare const MARGIN_KEY_PATTERN: RegExp;
export declare const ALIGNMENT_KEY_PATTERN: RegExp;
export declare const POSITION_KEY_PATTERN: RegExp;
export declare const GAP_KEY_PATTERN: RegExp;
export interface AlteredOptions {
    flex?: boolean;
    alignments?: boolean;
    paddings?: boolean;
    margins?: boolean;
    backgroundColor?: boolean;
    position?: boolean;
}
export interface ExtractedStyle {
    color?: string;
    typography?: TextStyle;
    backgroundColor?: string;
    borderRadius?: number;
    paddings?: Partial<Record<NativePaddingKeyType, number>>;
    margins?: Partial<Record<NativeMarginModifierKeyType, number>>;
    alignments?: ReturnType<typeof extractAlignmentsValues>;
    flexStyle?: Partial<Record<NativeFlexModifierKeyType, number>>;
    positionStyle?: ViewStyle;
    gap?: number;
}
export type ModifiersOptions = {
    color?: boolean;
    typography?: boolean;
    backgroundColor?: boolean;
    borderRadius?: boolean;
    paddings?: boolean;
    margins?: boolean;
    alignments?: boolean;
    flex?: boolean;
    position?: boolean;
    gap?: boolean;
};
declare const PADDING_VARIATIONS: {
    readonly padding: "padding";
    readonly paddingL: "paddingLeft";
    readonly paddingT: "paddingTop";
    readonly paddingR: "paddingRight";
    readonly paddingB: "paddingBottom";
    readonly paddingH: "paddingHorizontal";
    readonly paddingV: "paddingVertical";
};
declare const MARGIN_VARIATIONS: {
    readonly margin: "margin";
    readonly marginL: "marginLeft";
    readonly marginT: "marginTop";
    readonly marginR: "marginRight";
    readonly marginB: "marginBottom";
    readonly marginH: "marginHorizontal";
    readonly marginV: "marginVertical";
};
declare const STYLE_KEY_CONVERTERS: {
    readonly flex: "flex";
    readonly flexG: "flexGrow";
    readonly flexS: "flexShrink";
};
export type PaddingLiterals = keyof typeof PADDING_VARIATIONS;
export type NativePaddingKeyType = (typeof PADDING_VARIATIONS)[PaddingLiterals];
export type MarginLiterals = keyof typeof MARGIN_VARIATIONS;
export type NativeMarginModifierKeyType = (typeof MARGIN_VARIATIONS)[MarginLiterals];
export type FlexLiterals = keyof typeof STYLE_KEY_CONVERTERS;
export type NativeFlexModifierKeyType = (typeof STYLE_KEY_CONVERTERS)[FlexLiterals];
export type ColorLiterals = keyof (typeof colorsPalette & typeof DesignTokens);
export type TypographyLiterals = keyof typeof TypographyPresets;
export type BorderRadiusLiterals = keyof typeof BorderRadiusesLiterals;
export type AlignmentLiterals = 'row' | 'spread' | 'center' | 'centerH' | 'centerV' | 'left' | 'right' | 'top' | 'bottom';
export type PositionLiterals = 'absF' | 'absL' | 'absR' | 'absT' | 'absB' | 'absV' | 'absH';
export type GapLiterals = 'gap';
export type Modifier<T extends string> = Partial<Record<T, boolean>>;
export type CustomModifier = {
    [key: string]: boolean;
};
export type TypographyModifiers = Modifier<TypographyLiterals> | CustomModifier;
export type ColorsModifiers = Modifier<ColorLiterals> | CustomModifier;
export type BackgroundColorModifier = Modifier<`bg-${ColorLiterals}`>;
export type AlignmentModifiers = Modifier<AlignmentLiterals>;
export type PositionModifiers = Modifier<PositionLiterals>;
export type PaddingModifiers = Modifier<PaddingLiterals>;
export type MarginModifiers = Modifier<MarginLiterals>;
export type FlexModifiers = Modifier<FlexLiterals>;
export type BorderRadiusModifiers = Modifier<BorderRadiusLiterals>;
export type GapModifiers = Modifier<GapLiterals>;
export type ContainerModifiers = AlignmentModifiers & PositionModifiers & PaddingModifiers & MarginModifiers & FlexModifiers & BorderRadiusModifiers & BackgroundColorModifier & GapModifiers;
export declare function extractAlignmentsValues(props: Dictionary<any>): ViewStyle;
export declare function extractAccessibilityProps(props: Dictionary<any>): Dictionary<any>;
export declare const ANIMATION_PROPS: string[];
export declare function extractAnimationProps(props: Dictionary<any>): Dictionary<any>;
export declare function extractModifierProps(props: Dictionary<any>): Dictionary<any>;
export declare function extractComponentProps(component: any, props: Dictionary<any>, ignoreProps?: string[]): Dictionary<any>;
export declare function getThemeProps<T extends object>(props: T, context: Dictionary<any>, componentDisplayName?: string): T;
export declare function generateModifiersStyle(options: ModifiersOptions | undefined, props: Dictionary<any>): ExtractedStyle;
export {};
//# sourceMappingURL=modifiers.d.ts.map