import { type Dispatch, type SetStateAction } from 'react';
/**
 * setState that is safe to call after component unmounts.
 * @param initialState - initial state or function that returns initial state
 * @returns [state, safedSetState]
 * @example
 * function MyComponent() {
 * const [state, setState] = useSafeState(0);
 * return <button onClick={() => setState(state + 1)}>Increment</button>;
 * }
 */
export default function useSafeState<S>(initialState: S | (() => S)): [S, Dispatch<SetStateAction<S>>];
//# sourceMappingURL=useSafeState.d.ts.map